@@ -1,38 +1,26 @@
-# import json
-import asyncio
 import struct
 
-from ..const import CODE, DATA, DEVICE_TYPE, MESSAGE, ScreenLogicWarning
+from ..const import CODE, DATA, DEVICE_TYPE
 from .protocol import ScreenLogicProtocol
+from .request import async_make_request
 from .utility import getSome
 
 
-async def async_request_pump_status(protocol: ScreenLogicProtocol, data, pumpID):
-    try:
-        await asyncio.wait_for(
-            (
-                request := protocol.await_send_message(
-                    CODE.PUMPSTATUS_QUERY, struct.pack("<II", 0, pumpID)
-                )
-            ),
-            MESSAGE.COM_TIMEOUT,
-        )
-        if not request.cancelled():
-            decode_pump_status(request.result(), data, pumpID)
-    except asyncio.TimeoutError:
-        raise ScreenLogicWarning(f"Timeout poiling pump {pumpID} status")
+async def async_request_pump_status(
+    protocol: ScreenLogicProtocol, data: dict, pumpID: int
+) -> bytes:
+    if result := await async_make_request(
+        protocol, CODE.PUMPSTATUS_QUERY, struct.pack("<II", 0, pumpID)
+    ):
+        decode_pump_status(result, data, pumpID)
+        return result
 
 
-# pylint: disable=unused-variable
-def decode_pump_status(buff, data, pumpID):
-    # print(buff)
-    if DATA.KEY_PUMPS not in data:
-        data[DATA.KEY_PUMPS] = {}
+def decode_pump_status(buff: bytes, data: dict, pumpID: int) -> None:
+    pumps: dict = data.setdefault(DATA.KEY_PUMPS, {})
 
-    if pumpID not in data[DATA.KEY_PUMPS]:
-        data[DATA.KEY_PUMPS][pumpID] = {}
+    pump = pumps.setdefault(pumpID, {})
 
-    pump = data[DATA.KEY_PUMPS][pumpID]
     pump["name"] = ""
     pump["pumpType"], offset = getSome("I", buff, 0)
     pump["state"], offset = getSome("I", buff, offset)
@@ -43,13 +31,13 @@ def decode_pump_status(buff, data, pumpID):
     curR, offset = getSome("I", buff, offset)
     pump["currentRPM"] = {}  # Need to find value when unsupported.
 
-    unknown1, offset = getSome("I", buff, offset)
+    pump[f"unknown_at_offset_{offset:02}"], offset = getSome("I", buff, offset)
 
     curG, offset = getSome("I", buff, offset)
     if curG != 255:  # GPM reads 255 when unsupported.
         pump["currentGPM"] = {}
 
-    unknown2, offset = getSome("I", buff, offset)
+    pump[f"unknown_at_offset_{offset:02}"], offset = getSome("I", buff, offset)
 
     pump["presets"] = {}
     name = "Default"
@@ -91,4 +79,3 @@ def decode_pump_status(buff, data, pumpID):
             "value": curG,
             "unit": "gpm",
         }
-    # print(json.dumps(data, indent=4))
