@@ -1,7 +1,7 @@
 import struct
 from typing import List, Tuple
 
-from ..const import CODE, MESSAGE, ScreenLogicError
+from ..const import CODE, DATA, MESSAGE, ScreenLogicError, UNIT
 
 
 def makeMessage(msgID: int, msgCode: int, messageData: bytes = b""):
@@ -69,6 +69,26 @@ def getSome(want, buff, offset):
     return struct.unpack_from(fmt, buff, offset)[0], newoffset
 
 
+def getValueAt(buff, offset, want, **kwargs):
+    fmt = want if want.startswith(">") else "<" + want
+    val = kwargs.get("adjustment", lambda x: x)(
+        struct.unpack_from(fmt, buff, offset)[0]
+    )
+    if name := kwargs.get("name"):
+        data = {
+            "name": name,
+            "value": val,
+        }
+        if unit := kwargs.get("unit"):
+            data["unit"] = unit
+        if device_type := kwargs.get("device_type"):
+            data["device_type"] = device_type
+    else:
+        data = val
+    newoffset = offset + struct.calcsize(fmt)
+    return data, newoffset
+
+
 def getString(buff, offset):
     fmtLen = "<I"
     offsetLen = offset + struct.calcsize(fmtLen)
@@ -91,3 +111,13 @@ def getArray(buff, offset):
         offsetPad = (4 - itemCount % 4) % 4
         offset += offsetPad
     return items, offset
+
+
+def getTemperatureUnit(data: dict):
+    return (
+        UNIT.CELSIUS
+        if DATA.KEY_CONFIG in data
+        and "is_celsius" in data[DATA.KEY_CONFIG]
+        and data[DATA.KEY_CONFIG]["is_celsius"]["value"]
+        else UNIT.FAHRENHEIT
+    )
